==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ShapeFilterRecordEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ShapefileRecordDescriptionMetadata } from "./ShapefileRecordDescriptionMetadata";
import { ShapeFilterRecordEventArgsDescription } from "./ShapeFilterRecordEventArgsDescription";
/**
 * @hidden
 */
export let ShapeFilterRecordEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ShapeFilterRecordEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ShapeFilterRecordEventArgsDescriptionMetadata.a == null) {
                ShapeFilterRecordEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ShapeFilterRecordEventArgsDescriptionMetadata.c(ShapeFilterRecordEventArgsDescriptionMetadata.a);
            }
            if (a.j(ShapeFilterRecordEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ShapeFilterRecordEventArgsDescriptionMetadata.a);
            ShapefileRecordDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Record", "ExportedType:ShapefileRecord");
            a.item("ShouldInclude", "Boolean");
        }
        static d(a) {
            ShapeFilterRecordEventArgsDescriptionMetadata.b(a);
            a.aa("ShapeFilterRecordEventArgs", () => new ShapeFilterRecordEventArgsDescription());
            a.z("ShapeFilterRecordEventArgs", ShapeFilterRecordEventArgsDescriptionMetadata.a);
        }
    }
    ShapeFilterRecordEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ShapeFilterRecordEventArgsDescriptionMetadata, 'ShapeFilterRecordEventArgsDescriptionMetadata');
    ShapeFilterRecordEventArgsDescriptionMetadata.a = null;
    return ShapeFilterRecordEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ShapeFilterRecordEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ShapefileRecordDescriptionMetadata } from "./ShapefileRecordDescriptionMetadata";
import { ShapeFilterRecordEventArgsDescription } from "./ShapeFilterRecordEventArgsDescription";
/**
 * @hidden
 */
export let ShapeFilterRecordEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ShapeFilterRecordEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ShapeFilterRecordEventArgsDescriptionMetadata.a == null) {
                ShapeFilterRecordEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ShapeFilterRecordEventArgsDescriptionMetadata.c(ShapeFilterRecordEventArgsDescriptionMetadata.a);
            }
            if (a.k(ShapeFilterRecordEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ShapeFilterRecordEventArgsDescriptionMetadata.a);
            ShapefileRecordDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Record", "ExportedType:ShapefileRecord");
            a.item("ShouldInclude", "Boolean");
        }
        static d(a) {
            ShapeFilterRecordEventArgsDescriptionMetadata.b(a);
            a.ac("ShapeFilterRecordEventArgs", () => new ShapeFilterRecordEventArgsDescription());
            a.ab("ShapeFilterRecordEventArgs", ShapeFilterRecordEventArgsDescriptionMetadata.a);
        }
    }
    ShapeFilterRecordEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ShapeFilterRecordEventArgsDescriptionMetadata, 'ShapeFilterRecordEventArgsDescriptionMetadata');
    ShapeFilterRecordEventArgsDescriptionMetadata.a = null;
    return ShapeFilterRecordEventArgsDescriptionMetadata;
})();
